Class: Aws::InspectorScan::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::InspectorScan::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-inspectorscan/client.rb
Overview
An API client for InspectorScan. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::InspectorScan::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#scan_sbom(params = {}) ⇒ Types::ScanSbomResponse
Scans a provided CycloneDX 1.5 SBOM and reports on any vulnerabilities discovered in that SBOM.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
385 386 387 |
# File 'lib/aws-sdk-inspectorscan/client.rb', line 385 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
458 459 460 |
# File 'lib/aws-sdk-inspectorscan/client.rb', line 458 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
461 462 463 |
# File 'lib/aws-sdk-inspectorscan/client.rb', line 461 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/aws-sdk-inspectorscan/client.rb', line 436 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-inspectorscan' context[:gem_version] = '1.3.0' Seahorse::Client::Request.new(handlers, context) end |
#scan_sbom(params = {}) ⇒ Types::ScanSbomResponse
Scans a provided CycloneDX 1.5 SBOM and reports on any vulnerabilities discovered in that SBOM. You can generate compatible SBOMs for your resources using the [Amazon Inspector SBOM generator]().
427 428 429 430 |
# File 'lib/aws-sdk-inspectorscan/client.rb', line 427 def scan_sbom(params = {}, = {}) req = build_request(:scan_sbom, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
451 452 453 |
# File 'lib/aws-sdk-inspectorscan/client.rb', line 451 def waiter_names [] end |